package Perl::APIReference::V5_006_000;
use strict;
use warnings;
use parent 'Perl::APIReference';

sub new {
  my $class = shift;
  my $VAR1;

do{$VAR1 = {'isALNUM' => {'text' => 'Returns a boolean indicating whether the C C<char> is an ascii alphanumeric
character or digit.

	bool	isALNUM(char ch)','name' => 'isALNUM'},'SvSetSV_nosteal' => {'text' => 'Calls a non-destructive version of C<sv_setsv> if dsv is not the same as
ssv. May evaluate arguments more than once.

	void	SvSetSV_nosteal(SV* dsv, SV* ssv)','name' => 'SvSetSV_nosteal'},'HeHASH' => {'text' => 'Returns the computed hash stored in the hash entry.

	U32	HeHASH(HE* he)','name' => 'HeHASH'},'sv_catpvn_mg' => {'name' => 'sv_catpvn_mg','text' => 'Like C<sv_catpvn>, but also handles \'set\' magic.

	void	sv_catpvn_mg(SV *sv, const char *ptr, STRLEN len)'},'sv_setref_iv' => {'name' => 'sv_setref_iv','text' => 'Copies an integer into a new SV, optionally blessing the SV.  The C<rv>
argument will be upgraded to an RV.  That RV will be modified to point to
the new SV.  The C<classname> argument indicates the package for the
blessing.  Set C<classname> to C<Nullch> to avoid the blessing.  The new SV
will be returned and will have a reference count of 1.

	SV*	sv_setref_iv(SV* rv, const char* classname, IV iv)'},'sv_insert' => {'text' => 'Inserts a string at the specified offset/length within the SV. Similar to
the Perl substr() function.

	void	sv_insert(SV* bigsv, STRLEN offset, STRLEN len, char* little, STRLEN littlelen)','name' => 'sv_insert'},'ENTER' => {'name' => 'ENTER','text' => 'Opening bracket on a callback.  See C<LEAVE> and L<perlcall>.

		ENTER;'},'XPUSHi' => {'name' => 'XPUSHi','text' => 'Push an integer onto the stack, extending the stack if necessary.  Handles
\'set\' magic. See C<PUSHi>.

	void	XPUSHi(IV iv)'},'sv_setref_nv' => {'text' => 'Copies a double into a new SV, optionally blessing the SV.  The C<rv>
argument will be upgraded to an RV.  That RV will be modified to point to
the new SV.  The C<classname> argument indicates the package for the
blessing.  Set C<classname> to C<Nullch> to avoid the blessing.  The new SV
will be returned and will have a reference count of 1.

	SV*	sv_setref_nv(SV* rv, const char* classname, NV nv)','name' => 'sv_setref_nv'},'av_make' => {'name' => 'av_make','text' => 'Creates a new AV and populates it with a list of SVs.  The SVs are copied
into the array, so they may be freed after the call to av_make.  The new AV
will have a reference count of 1.

	AV*	av_make(I32 size, SV** svp)'},'Nullsv' => {'text' => 'Null SV pointer.','name' => 'Nullsv'},'newCONSTSUB' => {'name' => 'newCONSTSUB','text' => 'Creates a constant sub equivalent to Perl C<sub FOO () { 123 }> which is
eligible for inlining at compile-time.

	void	newCONSTSUB(HV* stash, char* name, SV* sv)'},'Nullcv' => {'text' => 'Null CV pointer.','name' => 'Nullcv'},'XST_mUNDEF' => {'name' => 'XST_mUNDEF','text' => 'Place C<&PL_sv_undef> into the specified position C<pos> on the
stack.

	void	XST_mUNDEF(int pos)'},'mg_free' => {'name' => 'mg_free','text' => 'Free any magic storage used by the SV.  See C<sv_magic>.

	int	mg_free(SV* sv)'},'G_ARRAY' => {'text' => 'Used to indicate array context.  See C<GIMME_V>, C<GIMME> and
L<perlcall>.','name' => 'G_ARRAY'},'PL_DBsub' => {'name' => 'PL_DBsub','text' => 'When Perl is run in debugging mode, with the B<-d> switch, this GV contains
the SV which holds the name of the sub being debugged.  This is the C
variable which corresponds to Perl\'s $DB::sub variable.  See
C<PL_DBsingle>.

	GV *	PL_DBsub'},'SvNOK' => {'text' => 'Returns a boolean indicating whether the SV contains a double.

	bool	SvNOK(SV* sv)','name' => 'SvNOK'},'SvTYPE' => {'text' => 'Returns the type of the SV.  See C<svtype>.

	svtype	SvTYPE(SV* sv)','name' => 'SvTYPE'},'newHV' => {'text' => 'Creates a new HV.  The reference count is set to 1.

	HV*	newHV()','name' => 'newHV'},'newAV' => {'name' => 'newAV','text' => 'Creates a new AV.  The reference count is set to 1.

	AV*	newAV()'},'CvSTASH' => {'name' => 'CvSTASH','text' => 'Returns the stash of the CV.

	HV*	CvSTASH(CV* cv)'},'Zero' => {'text' => 'The XSUB-writer\'s interface to the C C<memzero> function.  The C<dest> is the
destination, C<nitems> is the number of items, and C<type> is the type.

	void	Zero(void* dest, int nitems, type)','name' => 'Zero'},'G_NOARGS' => {'name' => 'G_NOARGS','text' => 'Indicates that no arguments are being sent to a callback.  See
L<perlcall>.'},'sv_setiv' => {'name' => 'sv_setiv','text' => 'Copies an integer into the given SV.  Does not handle \'set\' magic.  See
C<sv_setiv_mg>.

	void	sv_setiv(SV* sv, IV num)'},'sv_setuv' => {'name' => 'sv_setuv','text' => 'Copies an unsigned integer into the given SV.  Does not handle \'set\' magic.
See C<sv_setuv_mg>.

	void	sv_setuv(SV* sv, UV num)'},'mg_copy' => {'text' => 'Copies the magic from one SV to another.  See C<sv_magic>.

	int	mg_copy(SV* sv, SV* nsv, const char* key, I32 klen)','name' => 'mg_copy'},'SvUPGRADE' => {'text' => 'Used to upgrade an SV to a more complex form.  Uses C<sv_upgrade> to
perform the upgrade if necessary.  See C<svtype>.

	void	SvUPGRADE(SV* sv, svtype type)','name' => 'SvUPGRADE'},'SVt_IV' => {'name' => 'SVt_IV','text' => 'Integer type flag for scalars.  See C<svtype>.'},'SvREFCNT' => {'name' => 'SvREFCNT','text' => 'Returns the value of the object\'s reference count.

	U32	SvREFCNT(SV* sv)'},'newSViv' => {'name' => 'newSViv','text' => 'Creates a new SV and copies an integer into it.  The reference count for the
SV is set to 1.

	SV*	newSViv(IV i)'},'sv_eq' => {'text' => 'Returns a boolean indicating whether the strings in the two SVs are
identical.

	I32	sv_eq(SV* sv1, SV* sv2)','name' => 'sv_eq'},'SvCUR' => {'text' => 'Returns the length of the string which is in the SV.  See C<SvLEN>.

	STRLEN	SvCUR(SV* sv)','name' => 'SvCUR'},'SvPOK_off' => {'text' => 'Unsets the PV status of an SV.

	void	SvPOK_off(SV* sv)','name' => 'SvPOK_off'},'XPUSHu' => {'name' => 'XPUSHu','text' => 'Push an unsigned integer onto the stack, extending the stack if necessary. 
See C<PUSHu>.

	void	XPUSHu(UV uv)'},'newXSproto' => {'name' => 'newXSproto','text' => 'Used by C<xsubpp> to hook up XSUBs as Perl subs.  Adds Perl prototypes to
the subs.'},'PL_sv_undef' => {'name' => 'PL_sv_undef','text' => 'This is the C<undef> SV.  Always refer to this as C<&PL_sv_undef>.

	SV	PL_sv_undef'},'sv_setpv_mg' => {'text' => 'Like C<sv_setpv>, but also handles \'set\' magic.

	void	sv_setpv_mg(SV *sv, const char *ptr)','name' => 'sv_setpv_mg'},'sv_setpvf_mg' => {'text' => 'Like C<sv_setpvf>, but also handles \'set\' magic.

	void	sv_setpvf_mg(SV *sv, const char* pat, ...)','name' => 'sv_setpvf_mg'},'mg_length' => {'name' => 'mg_length','text' => 'Report on the SV\'s length.  See C<sv_magic>.

	U32	mg_length(SV* sv)'},'SvPOK_on' => {'text' => 'Tells an SV that it is a string.

	void	SvPOK_on(SV* sv)','name' => 'SvPOK_on'},'strLT' => {'text' => 'Test two strings to see if the first, C<s1>, is less than the second,
C<s2>.  Returns true or false.

	bool	strLT(char* s1, char* s2)','name' => 'strLT'},'XSRETURN_EMPTY' => {'text' => 'Return an empty list from an XSUB immediately.

		XSRETURN_EMPTY;','name' => 'XSRETURN_EMPTY'},'av_unshift' => {'text' => 'Unshift the given number of C<undef> values onto the beginning of the
array.  The array will grow automatically to accommodate the addition.  You
must then use C<av_store> to assign values to these new elements.

	void	av_unshift(AV* ar, I32 num)','name' => 'av_unshift'},'sv_unref' => {'text' => 'Unsets the RV status of the SV, and decrements the reference count of
whatever was being referenced by the RV.  This can almost be thought of
as a reversal of C<newSVrv>.  See C<SvROK_off>.

	void	sv_unref(SV* sv)','name' => 'sv_unref'},'call_sv' => {'text' => 'Performs a callback to the Perl sub whose name is in the SV.  See
L<perlcall>.

NOTE: the perl_ form of this function is deprecated.

	I32	call_sv(SV* sv, I32 flags)','name' => 'call_sv'},'fbm_instr' => {'name' => 'fbm_instr','text' => 'Returns the location of the SV in the string delimited by C<str> and
C<strend>.  It returns C<Nullch> if the string can\'t be found.  The C<sv>
does not have to be fbm_compiled, but the search will not be as fast
then.

	char*	fbm_instr(unsigned char* big, unsigned char* bigend, SV* littlesv, U32 flags)'},'XSRETURN_NV' => {'text' => 'Return an double from an XSUB immediately.  Uses C<XST_mNV>.

	void	XSRETURN_NV(NV nv)','name' => 'XSRETURN_NV'},'newSVpvn' => {'text' => 'Creates a new SV and copies a string into it.  The reference count for the
SV is set to 1.  Note that if C<len> is zero, Perl will create a zero length 
string.  You are responsible for ensuring that the source string is at least
C<len> bytes long.

	SV*	newSVpvn(const char* s, STRLEN len)','name' => 'newSVpvn'},'Nullch' => {'text' => 'Null character pointer.','name' => 'Nullch'},'XS_VERSION_BOOTCHECK' => {'text' => 'Macro to verify that a PM module\'s $VERSION variable matches the XS
module\'s C<XS_VERSION> variable.  This is usually handled automatically by
C<xsubpp>.  See L<perlxs/"The VERSIONCHECK: Keyword">.

		XS_VERSION_BOOTCHECK;','name' => 'XS_VERSION_BOOTCHECK'},'sv_len' => {'text' => 'Returns the length of the string in the SV.  See also C<SvCUR>.

	STRLEN	sv_len(SV* sv)','name' => 'sv_len'},'gv_fetchmeth' => {'name' => 'gv_fetchmeth','text' => 'Returns the glob with the given C<name> and a defined subroutine or
C<NULL>.  The glob lives in the given C<stash>, or in the stashes
accessible via @ISA and @UNIVERSAL. 

The argument C<level> should be either 0 or -1.  If C<level==0>, as a
side-effect creates a glob with the given C<name> in the given C<stash>
which in the case of success contains an alias for the subroutine, and sets
up caching info for this glob.  Similarly for all the searched stashes. 

This function grants C<"SUPER"> token as a postfix of the stash name. The
GV returned from C<gv_fetchmeth> may be a method cache entry, which is not
visible to Perl code.  So when calling C<call_sv>, you should not use
the GV directly; instead, you should use the method\'s CV, which can be
obtained from the GV with the C<GvCV> macro. 

	GV*	gv_fetchmeth(HV* stash, const char* name, STRLEN len, I32 level)'},'POPl' => {'text' => 'Pops a long off the stack.

	long	POPl','name' => 'POPl'},'New' => {'text' => 'The XSUB-writer\'s interface to the C C<malloc> function.

	void	New(int id, void* ptr, int nitems, type)','name' => 'New'},'SvNIOKp' => {'name' => 'SvNIOKp','text' => 'Returns a boolean indicating whether the SV contains a number, integer or
double.  Checks the B<private> setting.  Use C<SvNIOK>.

	bool	SvNIOKp(SV* sv)'},'Renewc' => {'name' => 'Renewc','text' => 'The XSUB-writer\'s interface to the C C<realloc> function, with
cast.

	void	Renewc(void* ptr, int nitems, type, cast)'},'call_argv' => {'text' => 'Performs a callback to the specified Perl sub.  See L<perlcall>.

NOTE: the perl_ form of this function is deprecated.

	I32	call_argv(const char* sub_name, I32 flags, char** argv)','name' => 'call_argv'},'hv_iternextsv' => {'text' => 'Performs an C<hv_iternext>, C<hv_iterkey>, and C<hv_iterval> in one
operation.

	SV*	hv_iternextsv(HV* hv, char** key, I32* retlen)','name' => 'hv_iternextsv'},'XS' => {'text' => 'Macro to declare an XSUB and its C parameter list.  This is handled by
C<xsubpp>.','name' => 'XS'},'av_fetch' => {'text' => 'Returns the SV at the specified index in the array.  The C<key> is the
index.  If C<lval> is set then the fetch will be part of a store.  Check
that the return value is non-null before dereferencing it to a C<SV*>.

See L<perlguts/"Understanding the Magic of Tied Hashes and Arrays"> for
more information on how to use this function on tied arrays. 

	SV**	av_fetch(AV* ar, I32 key, I32 lval)','name' => 'av_fetch'},'LEAVE' => {'name' => 'LEAVE','text' => 'Closing bracket on a callback.  See C<ENTER> and L<perlcall>.

		LEAVE;'},'sv_catpvn' => {'text' => 'Concatenates the string onto the end of the string which is in the SV.  The
C<len> indicates number of bytes to copy.  Handles \'get\' magic, but not
\'set\' magic.  See C<sv_catpvn_mg>.

	void	sv_catpvn(SV* sv, const char* ptr, STRLEN len)','name' => 'sv_catpvn'},'SvIOK_on' => {'name' => 'SvIOK_on','text' => 'Tells an SV that it is an integer.

	void	SvIOK_on(SV* sv)'},'av_len' => {'text' => 'Returns the highest index in the array.  Returns -1 if the array is
empty.

	I32	av_len(AV* ar)','name' => 'av_len'},'SvOK' => {'text' => 'Returns a boolean indicating whether the value is an SV.

	bool	SvOK(SV* sv)','name' => 'SvOK'},'sv_setsv' => {'text' => 'Copies the contents of the source SV C<ssv> into the destination SV C<dsv>.
The source SV may be destroyed if it is mortal.  Does not handle \'set\'
magic.  See the macro forms C<SvSetSV>, C<SvSetSV_nosteal> and
C<sv_setsv_mg>.

	void	sv_setsv(SV* dsv, SV* ssv)','name' => 'sv_setsv'},'sv_cmp' => {'name' => 'sv_cmp','text' => 'Compares the strings in two SVs.  Returns -1, 0, or 1 indicating whether the
string in C<sv1> is less than, equal to, or greater than the string in
C<sv2>.

	I32	sv_cmp(SV* sv1, SV* sv2)'},'ST' => {'name' => 'ST','text' => 'Used to access elements on the XSUB\'s stack.

	SV*	ST(int ix)'},'warn' => {'text' => 'This is the XSUB-writer\'s interface to Perl\'s C<warn> function.  Use this
function the same way you use the C C<printf> function.  See
C<croak>.

	void	warn(const char* pat, ...)','name' => 'warn'},'get_av' => {'name' => 'get_av','text' => 'Returns the AV of the specified Perl array.  If C<create> is set and the
Perl variable does not exist then it will be created.  If C<create> is not
set and the variable does not exist then NULL is returned.

NOTE: the perl_ form of this function is deprecated.

	AV*	get_av(const char* name, I32 create)'},'MARK' => {'name' => 'MARK','text' => 'Stack marker variable for the XSUB.  See C<dMARK>.'},'HeSVKEY' => {'name' => 'HeSVKEY','text' => 'Returns the key as an C<SV*>, or C<Nullsv> if the hash entry does not
contain an C<SV*> key.

	SV*	HeSVKEY(HE* he)'},'sv_2mortal' => {'text' => 'Marks an SV as mortal.  The SV will be destroyed when the current context
ends.

	SV*	sv_2mortal(SV* sv)','name' => 'sv_2mortal'},'SvSetSV' => {'name' => 'SvSetSV','text' => 'Calls C<sv_setsv> if dsv is not the same as ssv.  May evaluate arguments
more than once.

	void	SvSetSV(SV* dsb, SV* ssv)'},'SVt_PVHV' => {'name' => 'SVt_PVHV','text' => 'Type flag for hashes.  See C<svtype>.'},'sv_isobject' => {'name' => 'sv_isobject','text' => 'Returns a boolean indicating whether the SV is an RV pointing to a blessed
object.  If the SV is not an RV, or if the object is not blessed, then this
will return false.

	int	sv_isobject(SV* sv)'},'require_pv' => {'text' => 'Tells Perl to C<require> a module.

NOTE: the perl_ form of this function is deprecated.

	void	require_pv(const char* pv)','name' => 'require_pv'},'SvPOKp' => {'name' => 'SvPOKp','text' => 'Returns a boolean indicating whether the SV contains a character string.
Checks the B<private> setting.  Use C<SvPOK>.

	bool	SvPOKp(SV* sv)'},'StructCopy' => {'text' => 'This is an architecture-independant macro to copy one structure to another.

	void	StructCopy(type src, type dest, type)','name' => 'StructCopy'},'sv_chop' => {'name' => 'sv_chop','text' => 'Efficient removal of characters from the beginning of the string buffer. 
SvPOK(sv) must be true and the C<ptr> must be a pointer to somewhere inside
the string buffer.  The C<ptr> becomes the first character of the adjusted
string.

	void	sv_chop(SV* sv, char* ptr)'},'newRV_inc' => {'name' => 'newRV_inc','text' => 'Creates an RV wrapper for an SV.  The reference count for the original SV is
incremented.

	SV*	newRV_inc(SV* sv)'},'dSP' => {'text' => 'Declares a local copy of perl\'s stack pointer for the XSUB, available via
the C<SP> macro.  See C<SP>.

		dSP;','name' => 'dSP'},'savepv' => {'name' => 'savepv','text' => 'Copy a string to a safe spot.  This does not use an SV.

	char*	savepv(const char* sv)'},'SvNOK_only' => {'text' => 'Tells an SV that it is a double and disables all other OK bits.

	void	SvNOK_only(SV* sv)','name' => 'SvNOK_only'},'SvTAINTED_off' => {'name' => 'SvTAINTED_off','text' => 'Untaints an SV. Be I<very> careful with this routine, as it short-circuits
some of Perl\'s fundamental security features. XS module authors should not
use this function unless they fully understand all the implications of
unconditionally untainting the value. Untainting should be done in the
standard perl fashion, via a carefully crafted regexp, rather than directly
untainting variables.

	void	SvTAINTED_off(SV* sv)'},'toUPPER' => {'name' => 'toUPPER','text' => 'Converts the specified character to uppercase.

	char	toUPPER(char ch)'},'sv_grow' => {'text' => 'Expands the character buffer in the SV.  This will use C<sv_unref> and will
upgrade the SV to C<SVt_PV>.  Returns a pointer to the character buffer.
Use C<SvGROW>.

	char*	sv_grow(SV* sv, STRLEN newlen)','name' => 'sv_grow'},'sv_setiv_mg' => {'text' => 'Like C<sv_setiv>, but also handles \'set\' magic.

	void	sv_setiv_mg(SV *sv, IV i)','name' => 'sv_setiv_mg'},'XSRETURN_YES' => {'name' => 'XSRETURN_YES','text' => 'Return C<&PL_sv_yes> from an XSUB immediately.  Uses C<XST_mYES>.

		XSRETURN_YES;'},'av_push' => {'name' => 'av_push','text' => 'Pushes an SV onto the end of the array.  The array will grow automatically
to accommodate the addition.

	void	av_push(AV* ar, SV* val)'},'looks_like_number' => {'name' => 'looks_like_number','text' => 'Test if an the content of an SV looks like a number (or is a
number).

	I32	looks_like_number(SV* sv)'},'Newc' => {'text' => 'The XSUB-writer\'s interface to the C C<malloc> function, with
cast.

	void	Newc(int id, void* ptr, int nitems, type, cast)','name' => 'Newc'},'eval_pv' => {'name' => 'eval_pv','text' => 'Tells Perl to C<eval> the given string and return an SV* result.

NOTE: the perl_ form of this function is deprecated.

	SV*	eval_pv(const char* p, I32 croak_on_error)'},'hv_magic' => {'text' => 'Adds magic to a hash.  See C<sv_magic>.

	void	hv_magic(HV* hv, GV* gv, int how)','name' => 'hv_magic'},'HEf_SVKEY' => {'text' => 'This flag, used in the length slot of hash entries and magic structures,
specifies the structure contains a C<SV*> pointer where a C<char*> pointer
is to be expected. (For information only--not to be used).','name' => 'HEf_SVKEY'},'Safefree' => {'name' => 'Safefree','text' => 'The XSUB-writer\'s interface to the C C<free> function.

	void	Safefree(void* src, void* dest, int nitems, type)'},'G_SCALAR' => {'text' => 'Used to indicate scalar context.  See C<GIMME_V>, C<GIMME>, and
L<perlcall>.','name' => 'G_SCALAR'},'HeVAL' => {'name' => 'HeVAL','text' => 'Returns the value slot (type C<SV*>) stored in the hash entry.

	SV*	HeVAL(HE* he)'},'hv_store' => {'text' => 'Stores an SV in a hash.  The hash key is specified as C<key> and C<klen> is
the length of the key.  The C<hash> parameter is the precomputed hash
value; if it is zero then Perl will compute it.  The return value will be
NULL if the operation failed or if the value did not need to be actually
stored within the hash (as in the case of tied hashes).  Otherwise it can
be dereferenced to get the original C<SV*>.  Note that the caller is
responsible for suitably incrementing the reference count of C<val> before
the call, and decrementing it if the function returned NULL.  

See L<perlguts/"Understanding the Magic of Tied Hashes and Arrays"> for more
information on how to use this function on tied hashes.

	SV**	hv_store(HV* tb, const char* key, U32 klen, SV* val, U32 hash)','name' => 'hv_store'},'PUTBACK' => {'name' => 'PUTBACK','text' => 'Closing bracket for XSUB arguments.  This is usually handled by C<xsubpp>.
See C<PUSHMARK> and L<perlcall> for other uses.

		PUTBACK;'},'PL_sv_yes' => {'text' => 'This is the C<true> SV.  See C<PL_sv_no>.  Always refer to this as
C<&PL_sv_yes>.

	SV	PL_sv_yes','name' => 'PL_sv_yes'},'SvTAINTED' => {'text' => 'Checks to see if an SV is tainted. Returns TRUE if it is, FALSE if
not.

	bool	SvTAINTED(SV* sv)','name' => 'SvTAINTED'},'strGE' => {'name' => 'strGE','text' => 'Test two strings to see if the first, C<s1>, is greater than or equal to
the second, C<s2>.  Returns true or false.

	bool	strGE(char* s1, char* s2)'},'XPUSHn' => {'text' => 'Push a double onto the stack, extending the stack if necessary.  Handles
\'set\' magic.  See C<PUSHn>.

	void	XPUSHn(NV nv)','name' => 'XPUSHn'},'savepvn' => {'name' => 'savepvn','text' => 'Copy a string to a safe spot.  The C<len> indicates number of bytes to
copy.  This does not use an SV.

	char*	savepvn(const char* sv, I32 len)'},'Nullhv' => {'text' => 'Null HV pointer.','name' => 'Nullhv'},'PUSHs' => {'text' => 'Push an SV onto the stack.  The stack must have room for this element. 
Does not handle \'set\' magic.  See C<XPUSHs>.

	void	PUSHs(SV* sv)','name' => 'PUSHs'},'SvROK' => {'name' => 'SvROK','text' => 'Tests if the SV is an RV.

	bool	SvROK(SV* sv)'},'GIMME_V' => {'text' => 'The XSUB-writer\'s equivalent to Perl\'s C<wantarray>.  Returns C<G_VOID>,
C<G_SCALAR> or C<G_ARRAY> for void, scalar or array context,
respectively.

	U32	GIMME_V','name' => 'GIMME_V'},'av_shift' => {'text' => 'Shifts an SV off the beginning of the array.

	SV*	av_shift(AV* ar)','name' => 'av_shift'},'SVt_PV' => {'text' => 'Pointer type flag for scalars.  See C<svtype>.','name' => 'SVt_PV'},'CLASS' => {'text' => 'Variable which is setup by C<xsubpp> to indicate the 
class name for a C++ XS constructor.  This is always a C<char*>.  See C<THIS>.

	char*	CLASS','name' => 'CLASS'},'THIS' => {'text' => 'Variable which is setup by C<xsubpp> to designate the object in a C++ 
XSUB.  This is always the proper type for the C++ object.  See C<CLASS> and 
L<perlxs/"Using XS With C++">.

	(whatever)	THIS','name' => 'THIS'},'SvUV' => {'name' => 'SvUV','text' => 'Coerces the given SV to an unsigned integer and returns it.

	UV	SvUV(SV* sv)'},'HeSVKEY_force' => {'name' => 'HeSVKEY_force','text' => 'Returns the key as an C<SV*>.  Will create and return a temporary mortal
C<SV*> if the hash entry contains only a C<char*> key.

	SV*	HeSVKEY_force(HE* he)'},'sv_catpv' => {'text' => 'Concatenates the string onto the end of the string which is in the SV.
Handles \'get\' magic, but not \'set\' magic.  See C<sv_catpv_mg>.

	void	sv_catpv(SV* sv, const char* ptr)','name' => 'sv_catpv'},'sv_setref_pv' => {'name' => 'sv_setref_pv','text' => 'Copies a pointer into a new SV, optionally blessing the SV.  The C<rv>
argument will be upgraded to an RV.  That RV will be modified to point to
the new SV.  If the C<pv> argument is NULL then C<PL_sv_undef> will be placed
into the SV.  The C<classname> argument indicates the package for the
blessing.  Set C<classname> to C<Nullch> to avoid the blessing.  The new SV
will be returned and will have a reference count of 1.

Do not use with other Perl types such as HV, AV, SV, CV, because those
objects will become corrupted by the pointer copy process.

Note that C<sv_setref_pvn> copies the string while this copies the pointer.

	SV*	sv_setref_pv(SV* rv, const char* classname, void* pv)'},'POPi' => {'text' => 'Pops an integer off the stack.

	IV	POPi','name' => 'POPi'},'hv_undef' => {'text' => 'Undefines the hash.

	void	hv_undef(HV* tb)','name' => 'hv_undef'},'XSRETURN' => {'text' => 'Return from XSUB, indicating number of items on the stack.  This is usually
handled by C<xsubpp>.

	void	XSRETURN(int nitems)','name' => 'XSRETURN'},'sv_setnv' => {'name' => 'sv_setnv','text' => 'Copies a double into the given SV.  Does not handle \'set\' magic.  See
C<sv_setnv_mg>.

	void	sv_setnv(SV* sv, NV num)'},'dXSARGS' => {'text' => 'Sets up stack and mark pointers for an XSUB, calling dSP and dMARK.  This
is usually handled automatically by C<xsubpp>.  Declares the C<items>
variable to indicate the number of items on the stack.

		dXSARGS;','name' => 'dXSARGS'},'mg_magical' => {'text' => 'Turns on the magical status of an SV.  See C<sv_magic>.

	void	mg_magical(SV* sv)','name' => 'mg_magical'},'SAVETMPS' => {'text' => 'Opening bracket for temporaries on a callback.  See C<FREETMPS> and
L<perlcall>.

		SAVETMPS;','name' => 'SAVETMPS'},'newSVuv' => {'text' => 'Creates a new SV and copies an unsigned integer into it.
The reference count for the SV is set to 1.

	SV*	newSVuv(UV u)','name' => 'newSVuv'},'mg_clear' => {'name' => 'mg_clear','text' => 'Clear something magical that the SV represents.  See C<sv_magic>.

	int	mg_clear(SV* sv)'},'SvGETMAGIC' => {'name' => 'SvGETMAGIC','text' => 'Invokes C<mg_get> on an SV if it has \'get\' magic.  This macro evaluates its
argument more than once.

	void	SvGETMAGIC(SV* sv)'},'sv_catsv' => {'name' => 'sv_catsv','text' => 'Concatenates the string from SV C<ssv> onto the end of the string in SV
C<dsv>.  Handles \'get\' magic, but not \'set\' magic.  See C<sv_catsv_mg>.

	void	sv_catsv(SV* dsv, SV* ssv)'},'sv_setnv_mg' => {'text' => 'Like C<sv_setnv>, but also handles \'set\' magic.

	void	sv_setnv_mg(SV *sv, NV num)','name' => 'sv_setnv_mg'},'XSRETURN_IV' => {'text' => 'Return an integer from an XSUB immediately.  Uses C<XST_mIV>.

	void	XSRETURN_IV(IV iv)','name' => 'XSRETURN_IV'},'SvTRUE' => {'text' => 'Returns a boolean indicating whether Perl would evaluate the SV as true or
false, defined or undefined.  Does not handle \'get\' magic.

	bool	SvTRUE(SV* sv)','name' => 'SvTRUE'},'sv_setpv' => {'text' => 'Copies a string into an SV.  The string must be null-terminated.  Does not
handle \'set\' magic.  See C<sv_setpv_mg>.

	void	sv_setpv(SV* sv, const char* ptr)','name' => 'sv_setpv'},'toLOWER' => {'name' => 'toLOWER','text' => 'Converts the specified character to lowercase.

	char	toLOWER(char ch)'},'hv_iternext' => {'text' => 'Returns entries from a hash iterator.  See C<hv_iterinit>.

	HE*	hv_iternext(HV* tb)','name' => 'hv_iternext'},'SvEND' => {'text' => 'Returns a pointer to the last character in the string which is in the SV.
See C<SvCUR>.  Access the character as *(SvEND(sv)).

	char*	SvEND(SV* sv)','name' => 'SvEND'},'SvSETMAGIC' => {'text' => 'Invokes C<mg_set> on an SV if it has \'set\' magic.  This macro evaluates its
argument more than once.

	void	SvSETMAGIC(SV* sv)','name' => 'SvSETMAGIC'},'eval_sv' => {'text' => 'Tells Perl to C<eval> the string in the SV.

NOTE: the perl_ form of this function is deprecated.

	I32	eval_sv(SV* sv, I32 flags)','name' => 'eval_sv'},'sv_vcatpvfn' => {'text' => 'Processes its arguments like C<vsprintf> and appends the formatted output
to an SV.  Uses an array of SVs if the C style variable argument list is
missing (NULL).  When running with taint checks enabled, indicates via
C<maybe_tainted> if results are untrustworthy (often due to the use of
locales).

	void	sv_vcatpvfn(SV* sv, const char* pat, STRLEN patlen, va_list* args, SV** svargs, I32 svmax, bool *maybe_tainted)','name' => 'sv_vcatpvfn'},'GvSV' => {'text' => 'Return the SV from the GV.

	SV*	GvSV(GV* gv)','name' => 'GvSV'},'sv_setpvf' => {'name' => 'sv_setpvf','text' => 'Processes its arguments like C<sprintf> and sets an SV to the formatted
output.  Does not handle \'set\' magic.  See C<sv_setpvf_mg>.

	void	sv_setpvf(SV* sv, const char* pat, ...)'},'av_undef' => {'text' => 'Undefines the array.  Frees the memory used by the array itself.

	void	av_undef(AV* ar)','name' => 'av_undef'},'SVt_PVCV' => {'text' => 'Type flag for code refs.  See C<svtype>.','name' => 'SVt_PVCV'},'sv_mortalcopy' => {'text' => 'Creates a new SV which is a copy of the original SV.  The new SV is marked
as mortal.

	SV*	sv_mortalcopy(SV* oldsv)','name' => 'sv_mortalcopy'},'perl_alloc' => {'text' => 'Allocates a new Perl interpreter.  See L<perlembed>.

	PerlInterpreter*	perl_alloc()','name' => 'perl_alloc'},'SvROK_off' => {'name' => 'SvROK_off','text' => 'Unsets the RV status of an SV.

	void	SvROK_off(SV* sv)'},'GIMME' => {'text' => 'A backward-compatible version of C<GIMME_V> which can only return
C<G_SCALAR> or C<G_ARRAY>; in a void context, it returns C<G_SCALAR>.
Deprecated.  Use C<GIMME_V> instead.

	U32	GIMME','name' => 'GIMME'},'G_DISCARD' => {'text' => 'Indicates that arguments returned from a callback should be discarded.  See
L<perlcall>.','name' => 'G_DISCARD'},'av_clear' => {'text' => 'Clears an array, making it empty.  Does not free the memory used by the
array itself.

	void	av_clear(AV* ar)','name' => 'av_clear'},'hv_iterval' => {'name' => 'hv_iterval','text' => 'Returns the value from the current position of the hash iterator.  See
C<hv_iterkey>.

	SV*	hv_iterval(HV* tb, HE* entry)'},'SvPVX' => {'text' => 'Returns a pointer to the string in the SV.  The SV must contain a
string.

	char*	SvPVX(SV* sv)','name' => 'SvPVX'},'Move' => {'name' => 'Move','text' => 'The XSUB-writer\'s interface to the C C<memmove> function.  The C<src> is the
source, C<dest> is the destination, C<nitems> is the number of items, and C<type> is
the type.  Can do overlapping moves.  See also C<Copy>.

	void	Move(void* src, void* dest, int nitems, type)'},'newRV_noinc' => {'name' => 'newRV_noinc','text' => 'Creates an RV wrapper for an SV.  The reference count for the original
SV is B<not> incremented.

	SV*	newRV_noinc(SV *sv)'},'Newz' => {'name' => 'Newz','text' => 'The XSUB-writer\'s interface to the C C<malloc> function.  The allocated
memory is zeroed with C<memzero>.

	void	Newz(int id, void* ptr, int nitems, type)'},'newSVpvf' => {'text' => 'Creates a new SV an initialize it with the string formatted like
C<sprintf>.

	SV*	newSVpvf(const char* pat, ...)','name' => 'newSVpvf'},'SvTAINT' => {'text' => 'Taints an SV if tainting is enabled

	void	SvTAINT(SV* sv)','name' => 'SvTAINT'},'hv_clear' => {'name' => 'hv_clear','text' => 'Clears a hash, making it empty.

	void	hv_clear(HV* tb)'},'av_extend' => {'text' => 'Pre-extend an array.  The C<key> is the index to which the array should be
extended.

	void	av_extend(AV* ar, I32 key)','name' => 'av_extend'},'gv_fetchmethod' => {'text' => 'See L<gv_fetchmethod_autoload>.

	GV*	gv_fetchmethod(HV* stash, const char* name)','name' => 'gv_fetchmethod'},'sv_usepvn' => {'text' => 'Tells an SV to use C<ptr> to find its string value.  Normally the string is
stored inside the SV but sv_usepvn allows the SV to use an outside string. 
The C<ptr> should point to memory that was allocated by C<malloc>.  The
string length, C<len>, must be supplied.  This function will realloc the
memory pointed to by C<ptr>, so that pointer should not be freed or used by
the programmer after giving it to sv_usepvn.  Does not handle \'set\' magic.
See C<sv_usepvn_mg>.

	void	sv_usepvn(SV* sv, char* ptr, STRLEN len)','name' => 'sv_usepvn'},'sv_upgrade' => {'name' => 'sv_upgrade','text' => 'Upgrade an SV to a more complex form.  Use C<SvUPGRADE>.  See
C<svtype>.

	bool	sv_upgrade(SV* sv, U32 mt)'},'croak' => {'name' => 'croak','text' => 'This is the XSUB-writer\'s interface to Perl\'s C<die> function.  Use this
function the same way you use the C C<printf> function.  See
C<warn>.

	void	croak(const char* pat, ...)'},'strGT' => {'name' => 'strGT','text' => 'Test two strings to see if the first, C<s1>, is greater than the second,
C<s2>.  Returns true or false.

	bool	strGT(char* s1, char* s2)'},'SvOOK' => {'name' => 'SvOOK','text' => 'Returns a boolean indicating whether the SvIVX is a valid offset value for
the SvPVX.  This hack is used internally to speed up removal of characters
from the beginning of a SvPV.  When SvOOK is true, then the start of the
allocated string buffer is really (SvPVX - SvIVX).

	bool	SvOOK(SV* sv)'},'SvNOK_on' => {'name' => 'SvNOK_on','text' => 'Tells an SV that it is a double.

	void	SvNOK_on(SV* sv)'},'SvLEN' => {'name' => 'SvLEN','text' => 'Returns the size of the string buffer in the SV.  See C<SvCUR>.

	STRLEN	SvLEN(SV* sv)'},'sv_isa' => {'text' => 'Returns a boolean indicating whether the SV is blessed into the specified
class.  This does not check for subtypes; use C<sv_derived_from> to verify
an inheritance relationship.

	int	sv_isa(SV* sv, const char* name)','name' => 'sv_isa'},'items' => {'text' => 'Variable which is setup by C<xsubpp> to indicate the number of 
items on the stack.  See L<perlxs/"Variable-length Parameter Lists">.

	I32	items','name' => 'items'},'sv_setref_pvn' => {'text' => 'Copies a string into a new SV, optionally blessing the SV.  The length of the
string must be specified with C<n>.  The C<rv> argument will be upgraded to
an RV.  That RV will be modified to point to the new SV.  The C<classname>
argument indicates the package for the blessing.  Set C<classname> to
C<Nullch> to avoid the blessing.  The new SV will be returned and will have
a reference count of 1.

Note that C<sv_setref_pv> copies the pointer while this copies the string.

	SV*	sv_setref_pvn(SV* rv, const char* classname, char* pv, STRLEN n)','name' => 'sv_setref_pvn'},'XSRETURN_NO' => {'name' => 'XSRETURN_NO','text' => 'Return C<&PL_sv_no> from an XSUB immediately.  Uses C<XST_mNO>.

		XSRETURN_NO;'},'newSVrv' => {'name' => 'newSVrv','text' => 'Creates a new SV for the RV, C<rv>, to point to.  If C<rv> is not an RV then
it will be upgraded to one.  If C<classname> is non-null then the new SV will
be blessed in the specified package.  The new SV is returned and its
reference count is 1.

	SV*	newSVrv(SV* rv, const char* classname)'},'SvROK_on' => {'name' => 'SvROK_on','text' => 'Tells an SV that it is an RV.

	void	SvROK_on(SV* sv)'},'SvPOK' => {'text' => 'Returns a boolean indicating whether the SV contains a character
string.

	bool	SvPOK(SV* sv)','name' => 'SvPOK'},'strLE' => {'text' => 'Test two strings to see if the first, C<s1>, is less than or equal to the
second, C<s2>.  Returns true or false.

	bool	strLE(char* s1, char* s2)','name' => 'strLE'},'SvPV' => {'text' => 'Returns a pointer to the string in the SV, or a stringified form of the SV
if the SV does not contain a string.  Handles \'get\' magic.

	char*	SvPV(SV* sv, STRLEN len)','name' => 'SvPV'},'SvNV' => {'name' => 'SvNV','text' => 'Coerce the given SV to a double and return it.

	NV	SvNV(SV* sv)'},'sv_setpvn_mg' => {'text' => 'Like C<sv_setpvn>, but also handles \'set\' magic.

	void	sv_setpvn_mg(SV *sv, const char *ptr, STRLEN len)','name' => 'sv_setpvn_mg'},'dORIGMARK' => {'text' => 'Saves the original stack mark for the XSUB.  See C<ORIGMARK>.

		dORIGMARK;','name' => 'dORIGMARK'},'FREETMPS' => {'name' => 'FREETMPS','text' => 'Closing bracket for temporaries on a callback.  See C<SAVETMPS> and
L<perlcall>.

		FREETMPS;'},'POPp' => {'text' => 'Pops a string off the stack.

	char*	POPp','name' => 'POPp'},'SvNOKp' => {'text' => 'Returns a boolean indicating whether the SV contains a double.  Checks the
B<private> setting.  Use C<SvNOK>.

	bool	SvNOKp(SV* sv)','name' => 'SvNOKp'},'strEQ' => {'name' => 'strEQ','text' => 'Test two strings to see if they are equal.  Returns true or false.

	bool	strEQ(char* s1, char* s2)'},'SvIOKp' => {'text' => 'Returns a boolean indicating whether the SV contains an integer.  Checks
the B<private> setting.  Use C<SvIOK>.

	bool	SvIOKp(SV* sv)','name' => 'SvIOKp'},'hv_fetch_ent' => {'text' => 'Returns the hash entry which corresponds to the specified key in the hash.
C<hash> must be a valid precomputed hash number for the given C<key>, or 0
if you want the function to compute it.  IF C<lval> is set then the fetch
will be part of a store.  Make sure the return value is non-null before
accessing it.  The return value when C<tb> is a tied hash is a pointer to a
static location, so be sure to make a copy of the structure if you need to
store it somewhere. 

See L<perlguts/"Understanding the Magic of Tied Hashes and Arrays"> for more
information on how to use this function on tied hashes.

	HE*	hv_fetch_ent(HV* tb, SV* key, I32 lval, U32 hash)','name' => 'hv_fetch_ent'},'SvIOK_off' => {'text' => 'Unsets the IV status of an SV.

	void	SvIOK_off(SV* sv)','name' => 'SvIOK_off'},'sv_dec' => {'name' => 'sv_dec','text' => 'Auto-decrement of the value in the SV.

	void	sv_dec(SV* sv)'},'XST_mIV' => {'text' => 'Place an integer into the specified position C<pos> on the stack.  The
value is stored in a new mortal SV.

	void	XST_mIV(int pos, IV iv)','name' => 'XST_mIV'},'strnEQ' => {'name' => 'strnEQ','text' => 'Test two strings to see if they are equal.  The C<len> parameter indicates
the number of bytes to compare.  Returns true or false. (A wrapper for
C<strncmp>).

	bool	strnEQ(char* s1, char* s2, STRLEN len)'},'hv_iterkey' => {'text' => 'Returns the key from the current position of the hash iterator.  See
C<hv_iterinit>.

	char*	hv_iterkey(HE* entry, I32* retlen)','name' => 'hv_iterkey'},'SvRV' => {'text' => 'Dereferences an RV to return the SV.

	SV*	SvRV(SV* sv)','name' => 'SvRV'},'dMARK' => {'name' => 'dMARK','text' => 'Declare a stack marker variable, C<mark>, for the XSUB.  See C<MARK> and
C<dORIGMARK>.

		dMARK;'},'call_pv' => {'name' => 'call_pv','text' => 'Performs a callback to the specified Perl sub.  See L<perlcall>.

NOTE: the perl_ form of this function is deprecated.

	I32	call_pv(const char* sub_name, I32 flags)'},'PL_dowarn' => {'name' => 'PL_dowarn','text' => 'The C variable which corresponds to Perl\'s $^W warning variable.

	bool	PL_dowarn'},'sv_newmortal' => {'text' => 'Creates a new SV which is mortal.  The reference count of the SV is set to 1.

	SV*	sv_newmortal()','name' => 'sv_newmortal'},'sv_catsv_mg' => {'name' => 'sv_catsv_mg','text' => 'Like C<sv_catsv>, but also handles \'set\' magic.

	void	sv_catsv_mg(SV *dstr, SV *sstr)'},'sv_catpv_mg' => {'name' => 'sv_catpv_mg','text' => 'Like C<sv_catpv>, but also handles \'set\' magic.

	void	sv_catpv_mg(SV *sv, const char *ptr)'},'HePV' => {'text' => 'Returns the key slot of the hash entry as a C<char*> value, doing any
necessary dereferencing of possibly C<SV*> keys.  The length of the string
is placed in C<len> (this is a macro, so do I<not> use C<&len>).  If you do
not care about what the length of the key is, you may use the global
variable C<PL_na>, though this is rather less efficient than using a local
variable.  Remember though, that hash keys in perl are free to contain
embedded nulls, so using C<strlen()> or similar is not a good way to find
the length of hash keys. This is very similar to the C<SvPV()> macro
described elsewhere in this document.

	char*	HePV(HE* he, STRLEN len)','name' => 'HePV'},'SvGROW' => {'name' => 'SvGROW','text' => 'Expands the character buffer in the SV so that it has room for the
indicated number of bytes (remember to reserve space for an extra trailing
NUL character).  Calls C<sv_grow> to perform the expansion if necessary. 
Returns a pointer to the character buffer.

	void	SvGROW(SV* sv, STRLEN len)'},'hv_exists' => {'name' => 'hv_exists','text' => 'Returns a boolean indicating whether the specified hash key exists.  The
C<klen> is the length of the key.

	bool	hv_exists(HV* tb, const char* key, U32 klen)'},'sv_setpvn' => {'text' => 'Copies a string into an SV.  The C<len> parameter indicates the number of
bytes to be copied.  Does not handle \'set\' magic.  See C<sv_setpvn_mg>.

	void	sv_setpvn(SV* sv, const char* ptr, STRLEN len)','name' => 'sv_setpvn'},'hv_iterinit' => {'text' => 'Prepares a starting point to traverse a hash table.  Returns the number of
keys in the hash (i.e. the same as C<HvKEYS(tb)>).  The return value is
currently only meaningful for hashes without tie magic. 

NOTE: Before version 5.004_65, C<hv_iterinit> used to return the number of
hash buckets that happen to be in use.  If you still need that esoteric
value, you can get it through the macro C<HvFILL(tb)>.

	I32	hv_iterinit(HV* tb)','name' => 'hv_iterinit'},'SvCUR_set' => {'text' => 'Set the length of the string which is in the SV.  See C<SvCUR>.

	void	SvCUR_set(SV* sv, STRLEN len)','name' => 'SvCUR_set'},'SvNIOK_off' => {'text' => 'Unsets the NV/IV status of an SV.

	void	SvNIOK_off(SV* sv)','name' => 'SvNIOK_off'},'Copy' => {'text' => 'The XSUB-writer\'s interface to the C C<memcpy> function.  The C<src> is the
source, C<dest> is the destination, C<nitems> is the number of items, and C<type> is
the type.  May fail on overlapping copies.  See also C<Move>.

	void	Copy(void* src, void* dest, int nitems, type)','name' => 'Copy'},'perl_destruct' => {'name' => 'perl_destruct','text' => 'Shuts down a Perl interpreter.  See L<perlembed>.

	void	perl_destruct(PerlInterpreter* interp)'},'SvNVX' => {'text' => 'Returns the double which is stored in the SV, assuming SvNOK is
true.

	NV	SvNVX(SV* sv)','name' => 'SvNVX'},'XS_VERSION' => {'text' => 'The version identifier for an XS module.  This is usually
handled automatically by C<ExtUtils::MakeMaker>.  See C<XS_VERSION_BOOTCHECK>.','name' => 'XS_VERSION'},'ix' => {'name' => 'ix','text' => 'Variable which is setup by C<xsubpp> to indicate which of an 
XSUB\'s aliases was used to invoke it.  See L<perlxs/"The ALIAS: Keyword">.

	I32	ix'},'get_cv' => {'text' => 'Returns the CV of the specified Perl subroutine.  If C<create> is set and
the Perl subroutine does not exist then it will be declared (which has the
same effect as saying C<sub name;>).  If C<create> is not set and the
subroutine does not exist then NULL is returned.

NOTE: the perl_ form of this function is deprecated.

	CV*	get_cv(const char* name, I32 create)','name' => 'get_cv'},'isUPPER' => {'name' => 'isUPPER','text' => 'Returns a boolean indicating whether the C C<char> is an uppercase
character.

	bool	isUPPER(char ch)'},'POPn' => {'text' => 'Pops a double off the stack.

	NV	POPn','name' => 'POPn'},'svtype' => {'text' => 'An enum of flags for Perl types.  These are found in the file B<sv.h> 
in the C<svtype> enum.  Test these flags with the C<SvTYPE> macro.','name' => 'svtype'},'SVt_PVMG' => {'text' => 'Type flag for blessed scalars.  See C<svtype>.','name' => 'SVt_PVMG'},'newSVsv' => {'text' => 'Creates a new SV which is an exact duplicate of the original SV.

	SV*	newSVsv(SV* old)','name' => 'newSVsv'},'ORIGMARK' => {'name' => 'ORIGMARK','text' => 'The original stack mark for the XSUB.  See C<dORIGMARK>.'},'POPs' => {'name' => 'POPs','text' => 'Pops an SV off the stack.

	SV*	POPs'},'Renew' => {'text' => 'The XSUB-writer\'s interface to the C C<realloc> function.

	void	Renew(void* ptr, int nitems, type)','name' => 'Renew'},'sv_bless' => {'name' => 'sv_bless','text' => 'Blesses an SV into a specified package.  The SV must be an RV.  The package
must be designated by its stash (see C<gv_stashpv()>).  The reference count
of the SV is unaffected.

	SV*	sv_bless(SV* sv, HV* stash)'},'PL_modglobal' => {'text' => 'C<PL_modglobal> is a general purpose, interpreter global HV for use by 
extensions that need to keep information on a per-interpreter basis.
In a pinch, it can also be used as a symbol table for extensions 
to share data among each other.  It is a good idea to use keys 
prefixed by the package name of the extension that owns the data.

	HV*	PL_modglobal','name' => 'PL_modglobal'},'XST_mNO' => {'text' => 'Place C<&PL_sv_no> into the specified position C<pos> on the
stack.

	void	XST_mNO(int pos)','name' => 'XST_mNO'},'mg_set' => {'text' => 'Do magic after a value is assigned to the SV.  See C<sv_magic>.

	int	mg_set(SV* sv)','name' => 'mg_set'},'newXS' => {'text' => 'Used by C<xsubpp> to hook up XSUBs as Perl subs.','name' => 'newXS'},'HeKLEN' => {'text' => 'If this is negative, and amounts to C<HEf_SVKEY>, it indicates the entry
holds an C<SV*> key.  Otherwise, holds the actual length of the key.  Can
be assigned to. The C<HePV()> macro is usually preferable for finding key
lengths.

	STRLEN	HeKLEN(HE* he)','name' => 'HeKLEN'},'SPAGAIN' => {'name' => 'SPAGAIN','text' => 'Refetch the stack pointer.  Used after a callback.  See L<perlcall>.

		SPAGAIN;'},'perl_free' => {'name' => 'perl_free','text' => 'Releases a Perl interpreter.  See L<perlembed>.

	void	perl_free(PerlInterpreter* interp)'},'hv_delete' => {'name' => 'hv_delete','text' => 'Deletes a key/value pair in the hash.  The value SV is removed from the
hash and returned to the caller.  The C<klen> is the length of the key. 
The C<flags> value will normally be zero; if set to G_DISCARD then NULL
will be returned.

	SV*	hv_delete(HV* tb, const char* key, U32 klen, I32 flags)'},'XPUSHp' => {'name' => 'XPUSHp','text' => 'Push a string onto the stack, extending the stack if necessary.  The C<len>
indicates the length of the string.  Handles \'set\' magic.  See
C<PUSHp>.

	void	XPUSHp(char* str, STRLEN len)'},'isSPACE' => {'text' => 'Returns a boolean indicating whether the C C<char> is whitespace.

	bool	isSPACE(char ch)','name' => 'isSPACE'},'sv_usepvn_mg' => {'text' => 'Like C<sv_usepvn>, but also handles \'set\' magic.

	void	sv_usepvn_mg(SV *sv, char *ptr, STRLEN len)','name' => 'sv_usepvn_mg'},'PL_sv_no' => {'name' => 'PL_sv_no','text' => 'This is the C<false> SV.  See C<PL_sv_yes>.  Always refer to this as
C<&PL_sv_no>.

	SV	PL_sv_no'},'SvNIOK' => {'text' => 'Returns a boolean indicating whether the SV contains a number, integer or
double.

	bool	SvNIOK(SV* sv)','name' => 'SvNIOK'},'RETVAL' => {'text' => 'Variable which is setup by C<xsubpp> to hold the return value for an 
XSUB. This is always the proper type for the XSUB. See 
L<perlxs/"The RETVAL Variable">.

	(whatever)	RETVAL','name' => 'RETVAL'},'perl_parse' => {'name' => 'perl_parse','text' => 'Tells a Perl interpreter to parse a Perl script.  See L<perlembed>.

	int	perl_parse(PerlInterpreter* interp, XSINIT_t xsinit, int argc, char** argv, char** env)'},'sv_inc' => {'text' => 'Auto-increment of the value in the SV.

	void	sv_inc(SV* sv)','name' => 'sv_inc'},'av_store' => {'text' => 'Stores an SV in an array.  The array index is specified as C<key>.  The
return value will be NULL if the operation failed or if the value did not
need to be actually stored within the array (as in the case of tied
arrays). Otherwise it can be dereferenced to get the original C<SV*>.  Note
that the caller is responsible for suitably incrementing the reference
count of C<val> before the call, and decrementing it if the function
returned NULL.

See L<perlguts/"Understanding the Magic of Tied Hashes and Arrays"> for
more information on how to use this function on tied arrays.

	SV**	av_store(AV* ar, I32 key, SV* val)','name' => 'av_store'},'G_VOID' => {'name' => 'G_VOID','text' => 'Used to indicate void context.  See C<GIMME_V> and L<perlcall>.'},'AvFILL' => {'name' => 'AvFILL','text' => 'Same as C<av_len()>.  Deprecated, use C<av_len()> instead.

	int	AvFILL(AV* av)'},'XST_mPV' => {'text' => 'Place a copy of a string into the specified position C<pos> on the stack. 
The value is stored in a new mortal SV.

	void	XST_mPV(int pos, char* str)','name' => 'XST_mPV'},'PL_DBtrace' => {'text' => 'Trace variable used when Perl is run in debugging mode, with the B<-d>
switch.  This is the C variable which corresponds to Perl\'s $DB::trace
variable.  See C<PL_DBsingle>.

	SV *	PL_DBtrace','name' => 'PL_DBtrace'},'SVt_NV' => {'text' => 'Double type flag for scalars.  See C<svtype>.','name' => 'SVt_NV'},'XSRETURN_PV' => {'name' => 'XSRETURN_PV','text' => 'Return a copy of a string from an XSUB immediately.  Uses C<XST_mPV>.

	void	XSRETURN_PV(char* str)'},'SvSTASH' => {'text' => 'Returns the stash of the SV.

	HV*	SvSTASH(SV* sv)','name' => 'SvSTASH'},'PL_DBsingle' => {'text' => 'When Perl is run in debugging mode, with the B<-d> switch, this SV is a
boolean which indicates whether subs are being single-stepped. 
Single-stepping is automatically turned on after every step.  This is the C
variable which corresponds to Perl\'s $DB::single variable.  See
C<PL_DBsub>.

	SV *	PL_DBsingle','name' => 'PL_DBsingle'},'SvPV_force' => {'name' => 'SvPV_force','text' => 'Like <SvPV> but will force the SV into becoming a string (SvPOK).  You want
force if you are going to update the SvPVX directly.

	char*	SvPV_force(SV* sv, STRLEN len)'},'hv_store_ent' => {'name' => 'hv_store_ent','text' => 'Stores C<val> in a hash.  The hash key is specified as C<key>.  The C<hash>
parameter is the precomputed hash value; if it is zero then Perl will
compute it.  The return value is the new hash entry so created.  It will be
NULL if the operation failed or if the value did not need to be actually
stored within the hash (as in the case of tied hashes).  Otherwise the
contents of the return value can be accessed using the C<He???> macros
described here.  Note that the caller is responsible for suitably
incrementing the reference count of C<val> before the call, and
decrementing it if the function returned NULL. 

See L<perlguts/"Understanding the Magic of Tied Hashes and Arrays"> for more
information on how to use this function on tied hashes.

	HE*	hv_store_ent(HV* tb, SV* key, SV* val, U32 hash)'},'mg_get' => {'name' => 'mg_get','text' => 'Do magic after a value is retrieved from the SV.  See C<sv_magic>.

	int	mg_get(SV* sv)'},'PL_na' => {'text' => 'A convenience variable which is typically used with C<SvPV> when one
doesn\'t care about the length of the string.  It is usually more efficient
to either declare a local variable and use that instead or to use the
C<SvPV_nolen> macro.

	STRLEN	PL_na','name' => 'PL_na'},'sv_magic' => {'text' => 'Adds magic to an SV.

	void	sv_magic(SV* sv, SV* obj, int how, const char* name, I32 namlen)','name' => 'sv_magic'},'perl_run' => {'name' => 'perl_run','text' => 'Tells a Perl interpreter to run.  See L<perlembed>.

	int	perl_run(PerlInterpreter* interp)'},'sv_setsv_mg' => {'name' => 'sv_setsv_mg','text' => 'Like C<sv_setsv>, but also handles \'set\' magic.

	void	sv_setsv_mg(SV *dstr, SV *sstr)'},'NEWSV' => {'text' => 'Creates a new SV.  A non-zero C<len> parameter indicates the number of
bytes of preallocated string space the SV should have.  An extra byte for a
tailing NUL is also reserved.  (SvPOK is not set for the SV even if string
space is allocated.)  The reference count for the new SV is set to 1. 
C<id> is an integer id between 0 and 1299 (used to identify leaks).

	SV*	NEWSV(int id, STRLEN len)','name' => 'NEWSV'},'HeSVKEY_set' => {'name' => 'HeSVKEY_set','text' => 'Sets the key to a given C<SV*>, taking care to set the appropriate flags to
indicate the presence of an C<SV*> key, and returns the same
C<SV*>.

	SV*	HeSVKEY_set(HE* he, SV* sv)'},'PUSHu' => {'name' => 'PUSHu','text' => 'Push an unsigned integer onto the stack.  The stack must have room for this
element.  See C<XPUSHu>.

	void	PUSHu(UV uv)'},'hv_fetch' => {'text' => 'Returns the SV which corresponds to the specified key in the hash.  The
C<klen> is the length of the key.  If C<lval> is set then the fetch will be
part of a store.  Check that the return value is non-null before
dereferencing it to a C<SV*>. 

See L<perlguts/"Understanding the Magic of Tied Hashes and Arrays"> for more
information on how to use this function on tied hashes.

	SV**	hv_fetch(HV* tb, const char* key, U32 klen, I32 lval)','name' => 'hv_fetch'},'sv_derived_from' => {'text' => 'Returns a boolean indicating whether the SV is derived from the specified
class.  This is the function that implements C<UNIVERSAL::isa>.  It works
for class names as well as for objects.

	bool	sv_derived_from(SV* sv, const char* name)','name' => 'sv_derived_from'},'SvNOK_off' => {'text' => 'Unsets the NV status of an SV.

	void	SvNOK_off(SV* sv)','name' => 'SvNOK_off'},'SvTAINTED_on' => {'text' => 'Marks an SV as tainted.

	void	SvTAINTED_on(SV* sv)','name' => 'SvTAINTED_on'},'dXSI32' => {'name' => 'dXSI32','text' => 'Sets up the C<ix> variable for an XSUB which has aliases.  This is usually
handled automatically by C<xsubpp>.

		dXSI32;'},'strnNE' => {'text' => 'Test two strings to see if they are different.  The C<len> parameter
indicates the number of bytes to compare.  Returns true or false. (A
wrapper for C<strncmp>).

	bool	strnNE(char* s1, char* s2, STRLEN len)','name' => 'strnNE'},'isALPHA' => {'name' => 'isALPHA','text' => 'Returns a boolean indicating whether the C C<char> is an ascii alphabetic
character.

	bool	isALPHA(char ch)'},'XST_mYES' => {'name' => 'XST_mYES','text' => 'Place C<&PL_sv_yes> into the specified position C<pos> on the
stack.

	void	XST_mYES(int pos)'},'newSVpv' => {'name' => 'newSVpv','text' => 'Creates a new SV and copies a string into it.  The reference count for the
SV is set to 1.  If C<len> is zero, Perl will compute the length using
strlen().  For efficiency, consider using C<newSVpvn> instead.

	SV*	newSVpv(const char* s, STRLEN len)'},'sv_vsetpvfn' => {'text' => 'Works like C<vcatpvfn> but copies the text into the SV instead of
appending it.

	void	sv_vsetpvfn(SV* sv, const char* pat, STRLEN patlen, va_list* args, SV** svargs, I32 svmax, bool *maybe_tainted)','name' => 'sv_vsetpvfn'},'SvREFCNT_inc' => {'text' => 'Increments the reference count of the given SV.

	SV*	SvREFCNT_inc(SV* sv)','name' => 'SvREFCNT_inc'},'SvPOK_only' => {'text' => 'Tells an SV that it is a string and disables all other OK bits.

	void	SvPOK_only(SV* sv)','name' => 'SvPOK_only'},'PUSHp' => {'name' => 'PUSHp','text' => 'Push a string onto the stack.  The stack must have room for this element.
The C<len> indicates the length of the string.  Handles \'set\' magic.  See
C<XPUSHp>.

	void	PUSHp(char* str, STRLEN len)'},'G_EVAL' => {'text' => 'Used to force a Perl C<eval> wrapper around a callback.  See
L<perlcall>.','name' => 'G_EVAL'},'XPUSHs' => {'text' => 'Push an SV onto the stack, extending the stack if necessary.  Does not
handle \'set\' magic.  See C<PUSHs>.

	void	XPUSHs(SV* sv)','name' => 'XPUSHs'},'PUSHMARK' => {'text' => 'Opening bracket for arguments on a callback.  See C<PUTBACK> and
L<perlcall>.

		PUSHMARK;','name' => 'PUSHMARK'},'get_hv' => {'name' => 'get_hv','text' => 'Returns the HV of the specified Perl hash.  If C<create> is set and the
Perl variable does not exist then it will be created.  If C<create> is not
set and the variable does not exist then NULL is returned.

NOTE: the perl_ form of this function is deprecated.

	HV*	get_hv(const char* name, I32 create)'},'hv_iterkeysv' => {'name' => 'hv_iterkeysv','text' => 'Returns the key as an C<SV*> from the current position of the hash
iterator.  The return value will always be a mortal copy of the key.  Also
see C<hv_iterinit>.

	SV*	hv_iterkeysv(HE* entry)'},'XSRETURN_UNDEF' => {'name' => 'XSRETURN_UNDEF','text' => 'Return C<&PL_sv_undef> from an XSUB immediately.  Uses C<XST_mUNDEF>.

		XSRETURN_UNDEF;'},'HeKEY' => {'name' => 'HeKEY','text' => 'Returns the actual pointer stored in the key slot of the hash entry. The
pointer may be either C<char*> or C<SV*>, depending on the value of
C<HeKLEN()>.  Can be assigned to.  The C<HePV()> or C<HeSVKEY()> macros are
usually preferable for finding the value of a key.

	void*	HeKEY(HE* he)'},'sv_setuv_mg' => {'name' => 'sv_setuv_mg','text' => 'Like C<sv_setuv>, but also handles \'set\' magic.

	void	sv_setuv_mg(SV *sv, UV u)'},'gv_stashpv' => {'text' => 'Returns a pointer to the stash for a specified package.  C<name> should
be a valid UTF-8 string.  If C<create> is set then the package will be
created if it does not already exist.  If C<create> is not set and the
package does not exist then NULL is returned.

	HV*	gv_stashpv(const char* name, I32 create)','name' => 'gv_stashpv'},'XST_mNV' => {'text' => 'Place a double into the specified position C<pos> on the stack.  The value
is stored in a new mortal SV.

	void	XST_mNV(int pos, NV nv)','name' => 'XST_mNV'},'strNE' => {'name' => 'strNE','text' => 'Test two strings to see if they are different.  Returns true or
false.

	bool	strNE(char* s1, char* s2)'},'isLOWER' => {'name' => 'isLOWER','text' => 'Returns a boolean indicating whether the C C<char> is a lowercase
character.

	bool	isLOWER(char ch)'},'SvIOK' => {'name' => 'SvIOK','text' => 'Returns a boolean indicating whether the SV contains an integer.

	bool	SvIOK(SV* sv)'},'newSVnv' => {'name' => 'newSVnv','text' => 'Creates a new SV and copies a floating point value into it.
The reference count for the SV is set to 1.

	SV*	newSVnv(NV n)'},'sv_catpvf' => {'name' => 'sv_catpvf','text' => 'Processes its arguments like C<sprintf> and appends the formatted output
to an SV.  Handles \'get\' magic, but not \'set\' magic.  C<SvSETMAGIC()> must
typically be called after calling this function to handle \'set\' magic.

	void	sv_catpvf(SV* sv, const char* pat, ...)'},'get_sv' => {'name' => 'get_sv','text' => 'Returns the SV of the specified Perl scalar.  If C<create> is set and the
Perl variable does not exist then it will be created.  If C<create> is not
set and the variable does not exist then NULL is returned.

NOTE: the perl_ form of this function is deprecated.

	SV*	get_sv(const char* name, I32 create)'},'SvIV' => {'text' => 'Coerces the given SV to an integer and returns it.

	IV	SvIV(SV* sv)','name' => 'SvIV'},'hv_exists_ent' => {'text' => 'Returns a boolean indicating whether the specified hash key exists. C<hash>
can be a valid precomputed hash value, or 0 to ask for it to be
computed.

	bool	hv_exists_ent(HV* tb, SV* key, U32 hash)','name' => 'hv_exists_ent'},'sv_catpvf_mg' => {'name' => 'sv_catpvf_mg','text' => 'Like C<sv_catpvf>, but also handles \'set\' magic.

	void	sv_catpvf_mg(SV *sv, const char* pat, ...)'},'SVt_PVAV' => {'name' => 'SVt_PVAV','text' => 'Type flag for arrays.  See C<svtype>.'},'gv_stashsv' => {'name' => 'gv_stashsv','text' => 'Returns a pointer to the stash for a specified package, which must be a
valid UTF-8 string.  See C<gv_stashpv>.

	HV*	gv_stashsv(SV* sv, I32 create)'},'SvREFCNT_dec' => {'text' => 'Decrements the reference count of the given SV.

	void	SvREFCNT_dec(SV* sv)','name' => 'SvREFCNT_dec'},'fbm_compile' => {'name' => 'fbm_compile','text' => 'Analyses the string in order to make fast searches on it using fbm_instr()
-- the Boyer-Moore algorithm.

	void	fbm_compile(SV* sv, U32 flags)'},'mg_find' => {'name' => 'mg_find','text' => 'Finds the magic pointer for type matching the SV.  See C<sv_magic>.

	MAGIC*	mg_find(SV* sv, int type)'},'PUSHn' => {'name' => 'PUSHn','text' => 'Push a double onto the stack.  The stack must have room for this element.
Handles \'set\' magic.  See C<XPUSHn>.

	void	PUSHn(NV nv)'},'HvNAME' => {'text' => 'Returns the package name of a stash.  See C<SvSTASH>, C<CvSTASH>.

	char*	HvNAME(HV* stash)','name' => 'HvNAME'},'sv_setpviv_mg' => {'name' => 'sv_setpviv_mg','text' => 'Like C<sv_setpviv>, but also handles \'set\' magic.

	void	sv_setpviv_mg(SV *sv, IV iv)'},'SvPV_nolen' => {'name' => 'SvPV_nolen','text' => 'Returns a pointer to the string in the SV, or a stringified form of the SV
if the SV does not contain a string.  Handles \'get\' magic.

	char*	SvPV_nolen(SV* sv)'},'av_pop' => {'name' => 'av_pop','text' => 'Pops an SV off the end of the array.  Returns C<&PL_sv_undef> if the array
is empty.

	SV*	av_pop(AV* ar)'},'SvUVX' => {'text' => 'Returns the unsigned integer which is stored in the SV, assuming SvIOK is
true.

	UV	SvUVX(SV* sv)','name' => 'SvUVX'},'SP' => {'name' => 'SP','text' => 'Stack pointer.  This is usually handled by C<xsubpp>.  See C<dSP> and
C<SPAGAIN>.'},'isDIGIT' => {'text' => 'Returns a boolean indicating whether the C C<char> is an ascii
digit.

	bool	isDIGIT(char ch)','name' => 'isDIGIT'},'hv_delete_ent' => {'name' => 'hv_delete_ent','text' => 'Deletes a key/value pair in the hash.  The value SV is removed from the
hash and returned to the caller.  The C<flags> value will normally be zero;
if set to G_DISCARD then NULL will be returned.  C<hash> can be a valid
precomputed hash value, or 0 to ask for it to be computed.

	SV*	hv_delete_ent(HV* tb, SV* key, I32 flags, U32 hash)'},'perl_construct' => {'name' => 'perl_construct','text' => 'Initializes a new Perl interpreter.  See L<perlembed>.

	void	perl_construct(PerlInterpreter* interp)'},'call_method' => {'text' => 'Performs a callback to the specified Perl method.  The blessed object must
be on the stack.  See L<perlcall>.

NOTE: the perl_ form of this function is deprecated.

	I32	call_method(const char* methname, I32 flags)','name' => 'call_method'},'PUSHi' => {'text' => 'Push an integer onto the stack.  The stack must have room for this element.
Handles \'set\' magic.  See C<XPUSHi>.

	void	PUSHi(IV iv)','name' => 'PUSHi'},'SvIVX' => {'text' => 'Returns the integer which is stored in the SV, assuming SvIOK is
true.

	IV	SvIVX(SV* sv)','name' => 'SvIVX'},'EXTEND' => {'text' => 'Used to extend the argument stack for an XSUB\'s return values. Once
used, guarrantees that there is room for at least C<nitems> to be pushed
onto the stack.

	void	EXTEND(SP, int nitems)','name' => 'EXTEND'},'gv_fetchmethod_autoload' => {'text' => 'Returns the glob which contains the subroutine to call to invoke the method
on the C<stash>.  In fact in the presence of autoloading this may be the
glob for "AUTOLOAD".  In this case the corresponding variable $AUTOLOAD is
already setup. 

The third parameter of C<gv_fetchmethod_autoload> determines whether
AUTOLOAD lookup is performed if the given method is not present: non-zero
means yes, look for AUTOLOAD; zero means no, don\'t look for AUTOLOAD. 
Calling C<gv_fetchmethod> is equivalent to calling C<gv_fetchmethod_autoload>
with a non-zero C<autoload> parameter. 

These functions grant C<"SUPER"> token as a prefix of the method name. Note
that if you want to keep the returned glob for a long time, you need to
check for it being "AUTOLOAD", since at the later time the call may load a
different subroutine due to $AUTOLOAD changing its value. Use the glob
created via a side effect to do this. 

These functions have the same side-effects and as C<gv_fetchmeth> with
C<level==0>.  C<name> should be writable if contains C<\':\'> or C<\'
\'\'>. The warning against passing the GV returned by C<gv_fetchmeth> to
C<call_sv> apply equally to these functions. 

	GV*	gv_fetchmethod_autoload(HV* stash, const char* name, I32 autoload)','name' => 'gv_fetchmethod_autoload'},'SvIOK_only' => {'text' => 'Tells an SV that it is an integer and disables all other OK bits.

	void	SvIOK_only(SV* sv)','name' => 'SvIOK_only'},'sv_setpviv' => {'name' => 'sv_setpviv','text' => 'Copies an integer into the given SV, also updating its string value.
Does not handle \'set\' magic.  See C<sv_setpviv_mg>.

	void	sv_setpviv(SV* sv, IV num)'},'Nullav' => {'name' => 'Nullav','text' => 'Null AV pointer.'}};};

  my $self = bless({
    'index' => $VAR1,
    perl_version => '5.006',
  } => $class);
  return $self;
}

1;
